# coding: utf-8

"""
    VMware Cloud Director OpenAPI

    VMware Cloud Director OpenAPI is a new API that is defined using the OpenAPI standards.<br/> This ReSTful API borrows some elements of the legacy VMware Cloud Director API and establishes new patterns for use as described below. <h4>Authentication</h4> Authentication and Authorization schemes are the same as those for the legacy APIs. You can authenticate using the JWT token via the <code>Authorization</code> header or specifying a session using <code>x-vcloud-authorization</code> (The latter form is deprecated). <h4>Operation Patterns</h4> This API follows the following general guidelines to establish a consistent CRUD pattern: <table> <tr>   <th>Operation</th><th>Description</th><th>Response Code</th><th>Response Content</th> </tr><tr>   <td>GET /items<td>Returns a paginated list of items<td>200<td>Response will include Navigational links to the items in the list. </tr><tr>   <td>POST /items<td>Returns newly created item<td>201<td>Content-Location header links to the newly created item </tr><tr>   <td>GET /items/urn<td>Returns an individual item<td>200<td>A single item using same data type as that included in list above </tr><tr>   <td>PUT /items/urn<td>Updates an individual item<td>200<td>Updated view of the item is returned </tr><tr>   <td>DELETE /items/urn<td>Deletes the item<td>204<td>No content is returned. </tr> </table> <h5>Asynchronous operations</h5> Asynchronous operations are determined by the server. In those cases, instead of responding as described above, the server responds with an HTTP Response code 202 and an empty body. The tracking task (which is the same task as all legacy API operations use) is linked via the URI provided in the <code>Location</code> header.<br/> All API calls can choose to service a request asynchronously or synchronously as determined by the server upon interpreting the request. Operations that choose to exhibit this dual behavior will have both options documented by specifying both response code(s) below. The caller must be prepared to handle responses to such API calls by inspecting the HTTP Response code. <h5>Error Conditions</h5> <b>All</b> operations report errors using the following error reporting rules: <ul>   <li>400: Bad Request - In event of bad request due to incorrect data or other user error</li>   <li>401: Bad Request - If user is unauthenticated or their session has expired</li>   <li>403: Forbidden - If the user is not authorized or the entity does not exist</li> </ul> <h4>OpenAPI Design Concepts and Principles</h4> <ul>   <li>IDs are full Uniform Resource Names (URNs).</li>   <li>OpenAPI's <code>Content-Type</code> is always <code>application/json</code></li>   <li>REST links are in the Link header.</li>   <ul>     <li>Multiple relationships for any link are represented by multiple values in a space-separated list.</li>     <li>Links have a custom VMware Cloud Director-specific &quot;model&quot; attribute that hints at the applicable data         type for the links.</li>     <li>title + rel + model attributes evaluates to a unique link.</li>     <li>Links follow Hypermedia as the Engine of Application State (HATEOAS) principles. Links are present if         certain operations are present and permitted for the user&quot;s current role and the state of the         referred entities.</li>   </ul>   <li>APIs follow a flat structure relying on cross-referencing other entities instead of the navigational style       used by the legacy VMware Cloud Director APIs.</li>   <li>Most endpoints that return a list support filtering and sorting similar to the query service in the legacy       VMware Cloud Director APIs.</li>   <li>Accept header must be included to specify the API version for the request similar to calls to existing legacy       VMware Cloud Director APIs.</li>   <li>Each feature has a version in the path element present in its URL.<br/>       <b>Note</b> API URL's without a version in their paths must be considered experimental.</li> </ul> 

    OpenAPI spec version: 36.0
    Contact: https://code.vmware.com/support
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class CustomEntitiesApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def create_custom_entity_type(self, new_custom_entity_type, **kwargs):
        """
        Creates a new custom entity type
        Creates a new custom entity type 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_custom_entity_type(new_custom_entity_type, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CustomEntityType new_custom_entity_type: (required)
        :return: CustomEntityType
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_custom_entity_type_with_http_info(new_custom_entity_type, **kwargs)
        else:
            (data) = self.create_custom_entity_type_with_http_info(new_custom_entity_type, **kwargs)
            return data

    def create_custom_entity_type_with_http_info(self, new_custom_entity_type, **kwargs):
        """
        Creates a new custom entity type
        Creates a new custom entity type 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_custom_entity_type_with_http_info(new_custom_entity_type, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CustomEntityType new_custom_entity_type: (required)
        :return: CustomEntityType
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['new_custom_entity_type']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_custom_entity_type" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'new_custom_entity_type' is set
        if ('new_custom_entity_type' not in params) or (params['new_custom_entity_type'] is None):
            raise ValueError("Missing the required parameter `new_custom_entity_type` when calling `create_custom_entity_type`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'new_custom_entity_type' in params:
            body_params = params['new_custom_entity_type']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['ApiKeyAuth']

        return self.api_client.call_api('/customEntityTypes', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='CustomEntityType',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def create_custom_entity_type_action(self, new_custom_entity_type_action, custom_entity_type_id, **kwargs):
        """
        Creates a new custom entity type action.
        Creates a new custom entity type action 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_custom_entity_type_action(new_custom_entity_type_action, custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CreateCustomEntityTypeAction new_custom_entity_type_action: (required)
        :param str custom_entity_type_id: (required)
        :return: CustomEntityTypeAction
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_custom_entity_type_action_with_http_info(new_custom_entity_type_action, custom_entity_type_id, **kwargs)
        else:
            (data) = self.create_custom_entity_type_action_with_http_info(new_custom_entity_type_action, custom_entity_type_id, **kwargs)
            return data

    def create_custom_entity_type_action_with_http_info(self, new_custom_entity_type_action, custom_entity_type_id, **kwargs):
        """
        Creates a new custom entity type action.
        Creates a new custom entity type action 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_custom_entity_type_action_with_http_info(new_custom_entity_type_action, custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CreateCustomEntityTypeAction new_custom_entity_type_action: (required)
        :param str custom_entity_type_id: (required)
        :return: CustomEntityTypeAction
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['new_custom_entity_type_action', 'custom_entity_type_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_custom_entity_type_action" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'new_custom_entity_type_action' is set
        if ('new_custom_entity_type_action' not in params) or (params['new_custom_entity_type_action'] is None):
            raise ValueError("Missing the required parameter `new_custom_entity_type_action` when calling `create_custom_entity_type_action`")
        # verify the required parameter 'custom_entity_type_id' is set
        if ('custom_entity_type_id' not in params) or (params['custom_entity_type_id'] is None):
            raise ValueError("Missing the required parameter `custom_entity_type_id` when calling `create_custom_entity_type_action`")


        collection_formats = {}

        path_params = {}
        if 'custom_entity_type_id' in params:
            path_params['customEntityTypeId'] = params['custom_entity_type_id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'new_custom_entity_type_action' in params:
            body_params = params['new_custom_entity_type_action']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['ApiKeyAuth']

        return self.api_client.call_api('/customEntityTypes/{customEntityTypeId}/actions', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='CustomEntityTypeAction',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def delete_custom_entity_type(self, recursive, custom_entity_type_id, **kwargs):
        """
        Delete specified custom entity type.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_custom_entity_type(recursive, custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param bool recursive: if true, will recursively delete both custom entity type, all its instances and associated actions (required)
        :param str custom_entity_type_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_custom_entity_type_with_http_info(recursive, custom_entity_type_id, **kwargs)
        else:
            (data) = self.delete_custom_entity_type_with_http_info(recursive, custom_entity_type_id, **kwargs)
            return data

    def delete_custom_entity_type_with_http_info(self, recursive, custom_entity_type_id, **kwargs):
        """
        Delete specified custom entity type.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_custom_entity_type_with_http_info(recursive, custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param bool recursive: if true, will recursively delete both custom entity type, all its instances and associated actions (required)
        :param str custom_entity_type_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['recursive', 'custom_entity_type_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_custom_entity_type" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'recursive' is set
        if ('recursive' not in params) or (params['recursive'] is None):
            raise ValueError("Missing the required parameter `recursive` when calling `delete_custom_entity_type`")
        # verify the required parameter 'custom_entity_type_id' is set
        if ('custom_entity_type_id' not in params) or (params['custom_entity_type_id'] is None):
            raise ValueError("Missing the required parameter `custom_entity_type_id` when calling `delete_custom_entity_type`")


        collection_formats = {}

        path_params = {}
        if 'custom_entity_type_id' in params:
            path_params['customEntityTypeId'] = params['custom_entity_type_id']

        query_params = []
        if 'recursive' in params:
            query_params.append(('recursive', params['recursive']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['*/*'])

        # Authentication setting
        auth_settings = ['ApiKeyAuth']

        return self.api_client.call_api('/customEntityTypes/{customEntityTypeId}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def delete_custom_entity_type_action(self, custom_entity_type_id, workflow_id, **kwargs):
        """
        Delete specified custom entity type action
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_custom_entity_type_action(custom_entity_type_id, workflow_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str custom_entity_type_id: (required)
        :param str workflow_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_custom_entity_type_action_with_http_info(custom_entity_type_id, workflow_id, **kwargs)
        else:
            (data) = self.delete_custom_entity_type_action_with_http_info(custom_entity_type_id, workflow_id, **kwargs)
            return data

    def delete_custom_entity_type_action_with_http_info(self, custom_entity_type_id, workflow_id, **kwargs):
        """
        Delete specified custom entity type action
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_custom_entity_type_action_with_http_info(custom_entity_type_id, workflow_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str custom_entity_type_id: (required)
        :param str workflow_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['custom_entity_type_id', 'workflow_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_custom_entity_type_action" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'custom_entity_type_id' is set
        if ('custom_entity_type_id' not in params) or (params['custom_entity_type_id'] is None):
            raise ValueError("Missing the required parameter `custom_entity_type_id` when calling `delete_custom_entity_type_action`")
        # verify the required parameter 'workflow_id' is set
        if ('workflow_id' not in params) or (params['workflow_id'] is None):
            raise ValueError("Missing the required parameter `workflow_id` when calling `delete_custom_entity_type_action`")


        collection_formats = {}

        path_params = {}
        if 'custom_entity_type_id' in params:
            path_params['customEntityTypeId'] = params['custom_entity_type_id']
        if 'workflow_id' in params:
            path_params['workflowId'] = params['workflow_id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['*/*'])

        # Authentication setting
        auth_settings = ['ApiKeyAuth']

        return self.api_client.call_api('/customEntityTypes/{customEntityTypeId}/actions/{workflowId}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_custom_entities(self, **kwargs):
        """
        Get list of all custom entities
        Get list of custom entities 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_entities(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str filter: Filter for a query.  FIQL format.
        :param str sort_asc: Field to use for ascending sort
        :param str sort_desc: Field to use for descending sort
        :return: CustomEntities
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_custom_entities_with_http_info(**kwargs)
        else:
            (data) = self.get_custom_entities_with_http_info(**kwargs)
            return data

    def get_custom_entities_with_http_info(self, **kwargs):
        """
        Get list of all custom entities
        Get list of custom entities 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_entities_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str filter: Filter for a query.  FIQL format.
        :param str sort_asc: Field to use for ascending sort
        :param str sort_desc: Field to use for descending sort
        :return: CustomEntities
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter', 'sort_asc', 'sort_desc']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_custom_entities" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('filter', params['filter']))
        if 'sort_asc' in params:
            query_params.append(('sortAsc', params['sort_asc']))
        if 'sort_desc' in params:
            query_params.append(('sortDesc', params['sort_desc']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['ApiKeyAuth']

        return self.api_client.call_api('/customEntities', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='CustomEntities',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_custom_entity(self, custom_entity_id, **kwargs):
        """
        Get specified custom entity
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_entity(custom_entity_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str custom_entity_id: (required)
        :return: CustomEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_custom_entity_with_http_info(custom_entity_id, **kwargs)
        else:
            (data) = self.get_custom_entity_with_http_info(custom_entity_id, **kwargs)
            return data

    def get_custom_entity_with_http_info(self, custom_entity_id, **kwargs):
        """
        Get specified custom entity
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_entity_with_http_info(custom_entity_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str custom_entity_id: (required)
        :return: CustomEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['custom_entity_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_custom_entity" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'custom_entity_id' is set
        if ('custom_entity_id' not in params) or (params['custom_entity_id'] is None):
            raise ValueError("Missing the required parameter `custom_entity_id` when calling `get_custom_entity`")


        collection_formats = {}

        path_params = {}
        if 'custom_entity_id' in params:
            path_params['customEntityId'] = params['custom_entity_id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['ApiKeyAuth']

        return self.api_client.call_api('/customEntities/{customEntityId}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='CustomEntity',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_custom_entity_as_sdk_object(self, custom_entity_id, **kwargs):
        """
        Get specified custom entity represented as on Sdk-Object
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_entity_as_sdk_object(custom_entity_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str custom_entity_id: (required)
        :return: SdkObject
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_custom_entity_as_sdk_object_with_http_info(custom_entity_id, **kwargs)
        else:
            (data) = self.get_custom_entity_as_sdk_object_with_http_info(custom_entity_id, **kwargs)
            return data

    def get_custom_entity_as_sdk_object_with_http_info(self, custom_entity_id, **kwargs):
        """
        Get specified custom entity represented as on Sdk-Object
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_entity_as_sdk_object_with_http_info(custom_entity_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str custom_entity_id: (required)
        :return: SdkObject
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['custom_entity_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_custom_entity_as_sdk_object" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'custom_entity_id' is set
        if ('custom_entity_id' not in params) or (params['custom_entity_id'] is None):
            raise ValueError("Missing the required parameter `custom_entity_id` when calling `get_custom_entity_as_sdk_object`")


        collection_formats = {}

        path_params = {}
        if 'custom_entity_id' in params:
            path_params['customEntityId'] = params['custom_entity_id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['ApiKeyAuth']

        return self.api_client.call_api('/customEntities/{customEntityId}/sdkObject', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='SdkObject',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_custom_entity_type(self, custom_entity_type_id, **kwargs):
        """
        Get specified custom entity type
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_entity_type(custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str custom_entity_type_id: (required)
        :return: CustomEntityType
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_custom_entity_type_with_http_info(custom_entity_type_id, **kwargs)
        else:
            (data) = self.get_custom_entity_type_with_http_info(custom_entity_type_id, **kwargs)
            return data

    def get_custom_entity_type_with_http_info(self, custom_entity_type_id, **kwargs):
        """
        Get specified custom entity type
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_entity_type_with_http_info(custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str custom_entity_type_id: (required)
        :return: CustomEntityType
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['custom_entity_type_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_custom_entity_type" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'custom_entity_type_id' is set
        if ('custom_entity_type_id' not in params) or (params['custom_entity_type_id'] is None):
            raise ValueError("Missing the required parameter `custom_entity_type_id` when calling `get_custom_entity_type`")


        collection_formats = {}

        path_params = {}
        if 'custom_entity_type_id' in params:
            path_params['customEntityTypeId'] = params['custom_entity_type_id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['ApiKeyAuth']

        return self.api_client.call_api('/customEntityTypes/{customEntityTypeId}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='CustomEntityType',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_custom_entity_type_actions(self, custom_entity_type_id, **kwargs):
        """
        Get all actions associated with this custom entity type
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_entity_type_actions(custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str custom_entity_type_id: (required)
        :return: CustomEntityTypeActions
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_custom_entity_type_actions_with_http_info(custom_entity_type_id, **kwargs)
        else:
            (data) = self.get_custom_entity_type_actions_with_http_info(custom_entity_type_id, **kwargs)
            return data

    def get_custom_entity_type_actions_with_http_info(self, custom_entity_type_id, **kwargs):
        """
        Get all actions associated with this custom entity type
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_entity_type_actions_with_http_info(custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str custom_entity_type_id: (required)
        :return: CustomEntityTypeActions
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['custom_entity_type_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_custom_entity_type_actions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'custom_entity_type_id' is set
        if ('custom_entity_type_id' not in params) or (params['custom_entity_type_id'] is None):
            raise ValueError("Missing the required parameter `custom_entity_type_id` when calling `get_custom_entity_type_actions`")


        collection_formats = {}

        path_params = {}
        if 'custom_entity_type_id' in params:
            path_params['customEntityTypeId'] = params['custom_entity_type_id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['ApiKeyAuth']

        return self.api_client.call_api('/customEntityTypes/{customEntityTypeId}/actions', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='CustomEntityTypeActions',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_custom_entity_type_tenants(self, custom_entity_type_id, **kwargs):
        """
        Retrieves list of tenants for whom the custom entity type is explicitly published
        Retrieves list of item for whom the custom entity type is explicitly published 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_entity_type_tenants(custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str custom_entity_type_id: (required)
        :return: list[EntityReference]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_custom_entity_type_tenants_with_http_info(custom_entity_type_id, **kwargs)
        else:
            (data) = self.get_custom_entity_type_tenants_with_http_info(custom_entity_type_id, **kwargs)
            return data

    def get_custom_entity_type_tenants_with_http_info(self, custom_entity_type_id, **kwargs):
        """
        Retrieves list of tenants for whom the custom entity type is explicitly published
        Retrieves list of item for whom the custom entity type is explicitly published 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_entity_type_tenants_with_http_info(custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str custom_entity_type_id: (required)
        :return: list[EntityReference]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['custom_entity_type_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_custom_entity_type_tenants" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'custom_entity_type_id' is set
        if ('custom_entity_type_id' not in params) or (params['custom_entity_type_id'] is None):
            raise ValueError("Missing the required parameter `custom_entity_type_id` when calling `get_custom_entity_type_tenants`")


        collection_formats = {}

        path_params = {}
        if 'custom_entity_type_id' in params:
            path_params['customEntityTypeId'] = params['custom_entity_type_id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['ApiKeyAuth']

        return self.api_client.call_api('/customEntityTypes/{customEntityTypeId}/tenants', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[EntityReference]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def post_custom_entity_type_publish(self, publish_tenants_body, custom_entity_type_id, **kwargs):
        """
        Publishes the custom entity type to the specified tenants
        Publishes the custom entity type to the specified tenants 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_custom_entity_type_publish(publish_tenants_body, custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[EntityReference] publish_tenants_body: (required)
        :param str custom_entity_type_id: (required)
        :return: list[EntityReference]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.post_custom_entity_type_publish_with_http_info(publish_tenants_body, custom_entity_type_id, **kwargs)
        else:
            (data) = self.post_custom_entity_type_publish_with_http_info(publish_tenants_body, custom_entity_type_id, **kwargs)
            return data

    def post_custom_entity_type_publish_with_http_info(self, publish_tenants_body, custom_entity_type_id, **kwargs):
        """
        Publishes the custom entity type to the specified tenants
        Publishes the custom entity type to the specified tenants 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_custom_entity_type_publish_with_http_info(publish_tenants_body, custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[EntityReference] publish_tenants_body: (required)
        :param str custom_entity_type_id: (required)
        :return: list[EntityReference]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['publish_tenants_body', 'custom_entity_type_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_custom_entity_type_publish" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'publish_tenants_body' is set
        if ('publish_tenants_body' not in params) or (params['publish_tenants_body'] is None):
            raise ValueError("Missing the required parameter `publish_tenants_body` when calling `post_custom_entity_type_publish`")
        # verify the required parameter 'custom_entity_type_id' is set
        if ('custom_entity_type_id' not in params) or (params['custom_entity_type_id'] is None):
            raise ValueError("Missing the required parameter `custom_entity_type_id` when calling `post_custom_entity_type_publish`")


        collection_formats = {}

        path_params = {}
        if 'custom_entity_type_id' in params:
            path_params['customEntityTypeId'] = params['custom_entity_type_id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'publish_tenants_body' in params:
            body_params = params['publish_tenants_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['ApiKeyAuth']

        return self.api_client.call_api('/customEntityTypes/{customEntityTypeId}/tenants/publish', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[EntityReference]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def post_custom_entity_type_publish_all(self, custom_entity_type_id, **kwargs):
        """
        Publishes the custom entity type to all tenants
        Publishes the custom entity type to all tenants 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_custom_entity_type_publish_all(custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str custom_entity_type_id: (required)
        :return: list[EntityReference]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.post_custom_entity_type_publish_all_with_http_info(custom_entity_type_id, **kwargs)
        else:
            (data) = self.post_custom_entity_type_publish_all_with_http_info(custom_entity_type_id, **kwargs)
            return data

    def post_custom_entity_type_publish_all_with_http_info(self, custom_entity_type_id, **kwargs):
        """
        Publishes the custom entity type to all tenants
        Publishes the custom entity type to all tenants 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_custom_entity_type_publish_all_with_http_info(custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str custom_entity_type_id: (required)
        :return: list[EntityReference]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['custom_entity_type_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_custom_entity_type_publish_all" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'custom_entity_type_id' is set
        if ('custom_entity_type_id' not in params) or (params['custom_entity_type_id'] is None):
            raise ValueError("Missing the required parameter `custom_entity_type_id` when calling `post_custom_entity_type_publish_all`")


        collection_formats = {}

        path_params = {}
        if 'custom_entity_type_id' in params:
            path_params['customEntityTypeId'] = params['custom_entity_type_id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['ApiKeyAuth']

        return self.api_client.call_api('/customEntityTypes/{customEntityTypeId}/tenants/publishAll', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[EntityReference]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def post_custom_entity_type_unpublish(self, unpublish_tenants_body, custom_entity_type_id, **kwargs):
        """
        Revokes publication of the custom entity type to the specified tenants
        Revokes publication of the custom entity type to the specified tenants 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_custom_entity_type_unpublish(unpublish_tenants_body, custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[EntityReference] unpublish_tenants_body: (required)
        :param str custom_entity_type_id: (required)
        :return: list[EntityReference]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.post_custom_entity_type_unpublish_with_http_info(unpublish_tenants_body, custom_entity_type_id, **kwargs)
        else:
            (data) = self.post_custom_entity_type_unpublish_with_http_info(unpublish_tenants_body, custom_entity_type_id, **kwargs)
            return data

    def post_custom_entity_type_unpublish_with_http_info(self, unpublish_tenants_body, custom_entity_type_id, **kwargs):
        """
        Revokes publication of the custom entity type to the specified tenants
        Revokes publication of the custom entity type to the specified tenants 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_custom_entity_type_unpublish_with_http_info(unpublish_tenants_body, custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[EntityReference] unpublish_tenants_body: (required)
        :param str custom_entity_type_id: (required)
        :return: list[EntityReference]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['unpublish_tenants_body', 'custom_entity_type_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_custom_entity_type_unpublish" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'unpublish_tenants_body' is set
        if ('unpublish_tenants_body' not in params) or (params['unpublish_tenants_body'] is None):
            raise ValueError("Missing the required parameter `unpublish_tenants_body` when calling `post_custom_entity_type_unpublish`")
        # verify the required parameter 'custom_entity_type_id' is set
        if ('custom_entity_type_id' not in params) or (params['custom_entity_type_id'] is None):
            raise ValueError("Missing the required parameter `custom_entity_type_id` when calling `post_custom_entity_type_unpublish`")


        collection_formats = {}

        path_params = {}
        if 'custom_entity_type_id' in params:
            path_params['customEntityTypeId'] = params['custom_entity_type_id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'unpublish_tenants_body' in params:
            body_params = params['unpublish_tenants_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['ApiKeyAuth']

        return self.api_client.call_api('/customEntityTypes/{customEntityTypeId}/tenants/unpublish', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[EntityReference]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def post_custom_entity_type_unpublish_all(self, custom_entity_type_id, **kwargs):
        """
        Unpublishes the custom entity type from all tenants
        Unpublishes the custom entity type from all tenants 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_custom_entity_type_unpublish_all(custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str custom_entity_type_id: (required)
        :return: list[EntityReference]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.post_custom_entity_type_unpublish_all_with_http_info(custom_entity_type_id, **kwargs)
        else:
            (data) = self.post_custom_entity_type_unpublish_all_with_http_info(custom_entity_type_id, **kwargs)
            return data

    def post_custom_entity_type_unpublish_all_with_http_info(self, custom_entity_type_id, **kwargs):
        """
        Unpublishes the custom entity type from all tenants
        Unpublishes the custom entity type from all tenants 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_custom_entity_type_unpublish_all_with_http_info(custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str custom_entity_type_id: (required)
        :return: list[EntityReference]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['custom_entity_type_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_custom_entity_type_unpublish_all" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'custom_entity_type_id' is set
        if ('custom_entity_type_id' not in params) or (params['custom_entity_type_id'] is None):
            raise ValueError("Missing the required parameter `custom_entity_type_id` when calling `post_custom_entity_type_unpublish_all`")


        collection_formats = {}

        path_params = {}
        if 'custom_entity_type_id' in params:
            path_params['customEntityTypeId'] = params['custom_entity_type_id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['ApiKeyAuth']

        return self.api_client.call_api('/customEntityTypes/{customEntityTypeId}/tenants/unpublishAll', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[EntityReference]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def query_custom_entity_types(self, page, page_size, **kwargs):
        """
        Get list of all custom entity types
        Get list of custom entity types. 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.query_custom_entity_types(page, page_size, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int page: Page to fetch, zero offset. (required)
        :param int page_size: Results per page to fetch. (required)
        :param str filter: Filter for a query.  FIQL format.
        :param str sort_asc: Field to use for ascending sort
        :param str sort_desc: Field to use for descending sort
        :return: CustomEntityTypes
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.query_custom_entity_types_with_http_info(page, page_size, **kwargs)
        else:
            (data) = self.query_custom_entity_types_with_http_info(page, page_size, **kwargs)
            return data

    def query_custom_entity_types_with_http_info(self, page, page_size, **kwargs):
        """
        Get list of all custom entity types
        Get list of custom entity types. 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.query_custom_entity_types_with_http_info(page, page_size, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int page: Page to fetch, zero offset. (required)
        :param int page_size: Results per page to fetch. (required)
        :param str filter: Filter for a query.  FIQL format.
        :param str sort_asc: Field to use for ascending sort
        :param str sort_desc: Field to use for descending sort
        :return: CustomEntityTypes
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page', 'page_size', 'filter', 'sort_asc', 'sort_desc']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_custom_entity_types" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'page' is set
        if ('page' not in params) or (params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `query_custom_entity_types`")
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params) or (params['page_size'] is None):
            raise ValueError("Missing the required parameter `page_size` when calling `query_custom_entity_types`")

        if 'page' in params and params['page'] < 1:
            raise ValueError("Invalid value for parameter `page` when calling `query_custom_entity_types`, must be a value greater than or equal to `1`")
        if 'page_size' in params and params['page_size'] > 128:
            raise ValueError("Invalid value for parameter `page_size` when calling `query_custom_entity_types`, must be a value less than or equal to `128`")
        if 'page_size' in params and params['page_size'] < 0:
            raise ValueError("Invalid value for parameter `page_size` when calling `query_custom_entity_types`, must be a value greater than or equal to `0`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('filter', params['filter']))
        if 'sort_asc' in params:
            query_params.append(('sortAsc', params['sort_asc']))
        if 'sort_desc' in params:
            query_params.append(('sortDesc', params['sort_desc']))
        if 'page' in params:
            query_params.append(('page', params['page']))
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['ApiKeyAuth']

        return self.api_client.call_api('/customEntityTypes', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='CustomEntityTypes',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def set_custom_entity_type_tenants(self, publish_tenants_body, custom_entity_type_id, **kwargs):
        """
        Resets list of tenants for whom the custom entity type is explicitly published
        Resets list of tenants for whom the custom entity type is explicitly published 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.set_custom_entity_type_tenants(publish_tenants_body, custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[EntityReference] publish_tenants_body: (required)
        :param str custom_entity_type_id: (required)
        :return: list[EntityReference]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.set_custom_entity_type_tenants_with_http_info(publish_tenants_body, custom_entity_type_id, **kwargs)
        else:
            (data) = self.set_custom_entity_type_tenants_with_http_info(publish_tenants_body, custom_entity_type_id, **kwargs)
            return data

    def set_custom_entity_type_tenants_with_http_info(self, publish_tenants_body, custom_entity_type_id, **kwargs):
        """
        Resets list of tenants for whom the custom entity type is explicitly published
        Resets list of tenants for whom the custom entity type is explicitly published 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.set_custom_entity_type_tenants_with_http_info(publish_tenants_body, custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[EntityReference] publish_tenants_body: (required)
        :param str custom_entity_type_id: (required)
        :return: list[EntityReference]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['publish_tenants_body', 'custom_entity_type_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_custom_entity_type_tenants" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'publish_tenants_body' is set
        if ('publish_tenants_body' not in params) or (params['publish_tenants_body'] is None):
            raise ValueError("Missing the required parameter `publish_tenants_body` when calling `set_custom_entity_type_tenants`")
        # verify the required parameter 'custom_entity_type_id' is set
        if ('custom_entity_type_id' not in params) or (params['custom_entity_type_id'] is None):
            raise ValueError("Missing the required parameter `custom_entity_type_id` when calling `set_custom_entity_type_tenants`")


        collection_formats = {}

        path_params = {}
        if 'custom_entity_type_id' in params:
            path_params['customEntityTypeId'] = params['custom_entity_type_id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'publish_tenants_body' in params:
            body_params = params['publish_tenants_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['ApiKeyAuth']

        return self.api_client.call_api('/customEntityTypes/{customEntityTypeId}/tenants', 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[EntityReference]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def update_custom_entity_type(self, updated_custom_entity_type, custom_entity_type_id, **kwargs):
        """
        Update specified custom entity type
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_custom_entity_type(updated_custom_entity_type, custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CustomEntityType updated_custom_entity_type: (required)
        :param str custom_entity_type_id: (required)
        :return: CustomEntityType
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_custom_entity_type_with_http_info(updated_custom_entity_type, custom_entity_type_id, **kwargs)
        else:
            (data) = self.update_custom_entity_type_with_http_info(updated_custom_entity_type, custom_entity_type_id, **kwargs)
            return data

    def update_custom_entity_type_with_http_info(self, updated_custom_entity_type, custom_entity_type_id, **kwargs):
        """
        Update specified custom entity type
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_custom_entity_type_with_http_info(updated_custom_entity_type, custom_entity_type_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CustomEntityType updated_custom_entity_type: (required)
        :param str custom_entity_type_id: (required)
        :return: CustomEntityType
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['updated_custom_entity_type', 'custom_entity_type_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_custom_entity_type" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'updated_custom_entity_type' is set
        if ('updated_custom_entity_type' not in params) or (params['updated_custom_entity_type'] is None):
            raise ValueError("Missing the required parameter `updated_custom_entity_type` when calling `update_custom_entity_type`")
        # verify the required parameter 'custom_entity_type_id' is set
        if ('custom_entity_type_id' not in params) or (params['custom_entity_type_id'] is None):
            raise ValueError("Missing the required parameter `custom_entity_type_id` when calling `update_custom_entity_type`")


        collection_formats = {}

        path_params = {}
        if 'custom_entity_type_id' in params:
            path_params['customEntityTypeId'] = params['custom_entity_type_id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'updated_custom_entity_type' in params:
            body_params = params['updated_custom_entity_type']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['ApiKeyAuth']

        return self.api_client.call_api('/customEntityTypes/{customEntityTypeId}', 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='CustomEntityType',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)
