# coding: utf-8

"""
    VMware Cloud Director OpenAPI

    VMware Cloud Director OpenAPI is a new API that is defined using the OpenAPI standards.<br/> This ReSTful API borrows some elements of the legacy VMware Cloud Director API and establishes new patterns for use as described below. <h4>Authentication</h4> Authentication and Authorization schemes are the same as those for the legacy APIs. You can authenticate using the JWT token via the <code>Authorization</code> header or specifying a session using <code>x-vcloud-authorization</code> (The latter form is deprecated). <h4>Operation Patterns</h4> This API follows the following general guidelines to establish a consistent CRUD pattern: <table> <tr>   <th>Operation</th><th>Description</th><th>Response Code</th><th>Response Content</th> </tr><tr>   <td>GET /items<td>Returns a paginated list of items<td>200<td>Response will include Navigational links to the items in the list. </tr><tr>   <td>POST /items<td>Returns newly created item<td>201<td>Content-Location header links to the newly created item </tr><tr>   <td>GET /items/urn<td>Returns an individual item<td>200<td>A single item using same data type as that included in list above </tr><tr>   <td>PUT /items/urn<td>Updates an individual item<td>200<td>Updated view of the item is returned </tr><tr>   <td>DELETE /items/urn<td>Deletes the item<td>204<td>No content is returned. </tr> </table> <h5>Asynchronous operations</h5> Asynchronous operations are determined by the server. In those cases, instead of responding as described above, the server responds with an HTTP Response code 202 and an empty body. The tracking task (which is the same task as all legacy API operations use) is linked via the URI provided in the <code>Location</code> header.<br/> All API calls can choose to service a request asynchronously or synchronously as determined by the server upon interpreting the request. Operations that choose to exhibit this dual behavior will have both options documented by specifying both response code(s) below. The caller must be prepared to handle responses to such API calls by inspecting the HTTP Response code. <h5>Error Conditions</h5> <b>All</b> operations report errors using the following error reporting rules: <ul>   <li>400: Bad Request - In event of bad request due to incorrect data or other user error</li>   <li>401: Bad Request - If user is unauthenticated or their session has expired</li>   <li>403: Forbidden - If the user is not authorized or the entity does not exist</li> </ul> <h4>OpenAPI Design Concepts and Principles</h4> <ul>   <li>IDs are full Uniform Resource Names (URNs).</li>   <li>OpenAPI's <code>Content-Type</code> is always <code>application/json</code></li>   <li>REST links are in the Link header.</li>   <ul>     <li>Multiple relationships for any link are represented by multiple values in a space-separated list.</li>     <li>Links have a custom VMware Cloud Director-specific &quot;model&quot; attribute that hints at the applicable data         type for the links.</li>     <li>title + rel + model attributes evaluates to a unique link.</li>     <li>Links follow Hypermedia as the Engine of Application State (HATEOAS) principles. Links are present if         certain operations are present and permitted for the user&quot;s current role and the state of the         referred entities.</li>   </ul>   <li>APIs follow a flat structure relying on cross-referencing other entities instead of the navigational style       used by the legacy VMware Cloud Director APIs.</li>   <li>Most endpoints that return a list support filtering and sorting similar to the query service in the legacy       VMware Cloud Director APIs.</li>   <li>Accept header must be included to specify the API version for the request similar to calls to existing legacy       VMware Cloud Director APIs.</li>   <li>Each feature has a version in the path element present in its URL.<br/>       <b>Note</b> API URL's without a version in their paths must be considered experimental.</li> </ul> 

    OpenAPI spec version: 36.0
    Contact: https://code.vmware.com/support
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class EdgeBgpBfdConfig(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'enabled': 'bool',
        'bfd_interval': 'int',
        'declare_dead_multiple': 'int'
    }

    attribute_map = {
        'enabled': 'enabled',
        'bfd_interval': 'bfdInterval',
        'declare_dead_multiple': 'declareDeadMultiple'
    }

    def __init__(self, enabled=False, bfd_interval=1000, declare_dead_multiple=3):
        """
        EdgeBgpBfdConfig - a model defined in Swagger
        """

        self._enabled = None
        self._bfd_interval = None
        self._declare_dead_multiple = None

        if enabled is not None:
          self.enabled = enabled
        if bfd_interval is not None:
          self.bfd_interval = bfd_interval
        if declare_dead_multiple is not None:
          self.declare_dead_multiple = declare_dead_multiple

    @property
    def enabled(self):
        """
        Gets the enabled of this EdgeBgpBfdConfig.
        A flag indicating whether BFD configuration is enabled or not.

        :return: The enabled of this EdgeBgpBfdConfig.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this EdgeBgpBfdConfig.
        A flag indicating whether BFD configuration is enabled or not.

        :param enabled: The enabled of this EdgeBgpBfdConfig.
        :type: bool
        """

        self._enabled = enabled

    @property
    def bfd_interval(self):
        """
        Gets the bfd_interval of this EdgeBgpBfdConfig.
        Specifies the time interval (in milliseconds) between heartbeat packets.

        :return: The bfd_interval of this EdgeBgpBfdConfig.
        :rtype: int
        """
        return self._bfd_interval

    @bfd_interval.setter
    def bfd_interval(self, bfd_interval):
        """
        Sets the bfd_interval of this EdgeBgpBfdConfig.
        Specifies the time interval (in milliseconds) between heartbeat packets.

        :param bfd_interval: The bfd_interval of this EdgeBgpBfdConfig.
        :type: int
        """
        if bfd_interval is not None and bfd_interval > 60000:
            raise ValueError("Invalid value for `bfd_interval`, must be a value less than or equal to `60000`")
        if bfd_interval is not None and bfd_interval < 300:
            raise ValueError("Invalid value for `bfd_interval`, must be a value greater than or equal to `300`")

        self._bfd_interval = bfd_interval

    @property
    def declare_dead_multiple(self):
        """
        Gets the declare_dead_multiple of this EdgeBgpBfdConfig.
        Number of times heartbeat packet is missed before BFD declares that the neighbor is down.

        :return: The declare_dead_multiple of this EdgeBgpBfdConfig.
        :rtype: int
        """
        return self._declare_dead_multiple

    @declare_dead_multiple.setter
    def declare_dead_multiple(self, declare_dead_multiple):
        """
        Sets the declare_dead_multiple of this EdgeBgpBfdConfig.
        Number of times heartbeat packet is missed before BFD declares that the neighbor is down.

        :param declare_dead_multiple: The declare_dead_multiple of this EdgeBgpBfdConfig.
        :type: int
        """
        if declare_dead_multiple is not None and declare_dead_multiple > 16:
            raise ValueError("Invalid value for `declare_dead_multiple`, must be a value less than or equal to `16`")
        if declare_dead_multiple is not None and declare_dead_multiple < 2:
            raise ValueError("Invalid value for `declare_dead_multiple`, must be a value greater than or equal to `2`")

        self._declare_dead_multiple = declare_dead_multiple

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, EdgeBgpBfdConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
