# coding: utf-8

"""
    VMware Cloud Director OpenAPI

    VMware Cloud Director OpenAPI is a new API that is defined using the OpenAPI standards.<br/> This ReSTful API borrows some elements of the legacy VMware Cloud Director API and establishes new patterns for use as described below. <h4>Authentication</h4> Authentication and Authorization schemes are the same as those for the legacy APIs. You can authenticate using the JWT token via the <code>Authorization</code> header or specifying a session using <code>x-vcloud-authorization</code> (The latter form is deprecated). <h4>Operation Patterns</h4> This API follows the following general guidelines to establish a consistent CRUD pattern: <table> <tr>   <th>Operation</th><th>Description</th><th>Response Code</th><th>Response Content</th> </tr><tr>   <td>GET /items<td>Returns a paginated list of items<td>200<td>Response will include Navigational links to the items in the list. </tr><tr>   <td>POST /items<td>Returns newly created item<td>201<td>Content-Location header links to the newly created item </tr><tr>   <td>GET /items/urn<td>Returns an individual item<td>200<td>A single item using same data type as that included in list above </tr><tr>   <td>PUT /items/urn<td>Updates an individual item<td>200<td>Updated view of the item is returned </tr><tr>   <td>DELETE /items/urn<td>Deletes the item<td>204<td>No content is returned. </tr> </table> <h5>Asynchronous operations</h5> Asynchronous operations are determined by the server. In those cases, instead of responding as described above, the server responds with an HTTP Response code 202 and an empty body. The tracking task (which is the same task as all legacy API operations use) is linked via the URI provided in the <code>Location</code> header.<br/> All API calls can choose to service a request asynchronously or synchronously as determined by the server upon interpreting the request. Operations that choose to exhibit this dual behavior will have both options documented by specifying both response code(s) below. The caller must be prepared to handle responses to such API calls by inspecting the HTTP Response code. <h5>Error Conditions</h5> <b>All</b> operations report errors using the following error reporting rules: <ul>   <li>400: Bad Request - In event of bad request due to incorrect data or other user error</li>   <li>401: Bad Request - If user is unauthenticated or their session has expired</li>   <li>403: Forbidden - If the user is not authorized or the entity does not exist</li> </ul> <h4>OpenAPI Design Concepts and Principles</h4> <ul>   <li>IDs are full Uniform Resource Names (URNs).</li>   <li>OpenAPI's <code>Content-Type</code> is always <code>application/json</code></li>   <li>REST links are in the Link header.</li>   <ul>     <li>Multiple relationships for any link are represented by multiple values in a space-separated list.</li>     <li>Links have a custom VMware Cloud Director-specific &quot;model&quot; attribute that hints at the applicable data         type for the links.</li>     <li>title + rel + model attributes evaluates to a unique link.</li>     <li>Links follow Hypermedia as the Engine of Application State (HATEOAS) principles. Links are present if         certain operations are present and permitted for the user&quot;s current role and the state of the         referred entities.</li>   </ul>   <li>APIs follow a flat structure relying on cross-referencing other entities instead of the navigational style       used by the legacy VMware Cloud Director APIs.</li>   <li>Most endpoints that return a list support filtering and sorting similar to the query service in the legacy       VMware Cloud Director APIs.</li>   <li>Accept header must be included to specify the API version for the request similar to calls to existing legacy       VMware Cloud Director APIs.</li>   <li>Each feature has a version in the path element present in its URL.<br/>       <b>Note</b> API URL's without a version in their paths must be considered experimental.</li> </ul> 

    OpenAPI spec version: 36.0
    Contact: https://code.vmware.com/support
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class EdgeBgpGracefulRestartConfig(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'mode': 'GracefulRestartModeTypes',
        'restart_timer': 'int',
        'stale_route_timer': 'int'
    }

    attribute_map = {
        'mode': 'mode',
        'restart_timer': 'restartTimer',
        'stale_route_timer': 'staleRouteTimer'
    }

    def __init__(self, mode=None, restart_timer=180, stale_route_timer=600):
        """
        EdgeBgpGracefulRestartConfig - a model defined in Swagger
        """

        self._mode = None
        self._restart_timer = None
        self._stale_route_timer = None

        if mode is not None:
          self.mode = mode
        if restart_timer is not None:
          self.restart_timer = restart_timer
        if stale_route_timer is not None:
          self.stale_route_timer = stale_route_timer

    @property
    def mode(self):
        """
        Gets the mode of this EdgeBgpGracefulRestartConfig.
        Currently configured graceful restart mode. Default is HELPER_ONLY.

        :return: The mode of this EdgeBgpGracefulRestartConfig.
        :rtype: GracefulRestartModeTypes
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """
        Sets the mode of this EdgeBgpGracefulRestartConfig.
        Currently configured graceful restart mode. Default is HELPER_ONLY.

        :param mode: The mode of this EdgeBgpGracefulRestartConfig.
        :type: GracefulRestartModeTypes
        """

        self._mode = mode

    @property
    def restart_timer(self):
        """
        Gets the restart_timer of this EdgeBgpGracefulRestartConfig.
        Maximum time taken (in seconds) for a BGP session to be established after a restart. If the session is not re-established within this timer, the receiving speaker will delete all the stale routes from that peer. 

        :return: The restart_timer of this EdgeBgpGracefulRestartConfig.
        :rtype: int
        """
        return self._restart_timer

    @restart_timer.setter
    def restart_timer(self, restart_timer):
        """
        Sets the restart_timer of this EdgeBgpGracefulRestartConfig.
        Maximum time taken (in seconds) for a BGP session to be established after a restart. If the session is not re-established within this timer, the receiving speaker will delete all the stale routes from that peer. 

        :param restart_timer: The restart_timer of this EdgeBgpGracefulRestartConfig.
        :type: int
        """
        if restart_timer is not None and restart_timer > 3600:
            raise ValueError("Invalid value for `restart_timer`, must be a value less than or equal to `3600`")
        if restart_timer is not None and restart_timer < 1:
            raise ValueError("Invalid value for `restart_timer`, must be a value greater than or equal to `1`")

        self._restart_timer = restart_timer

    @property
    def stale_route_timer(self):
        """
        Gets the stale_route_timer of this EdgeBgpGracefulRestartConfig.
        Maximum time (in seconds) before stale routes are removed when BGP restarts.

        :return: The stale_route_timer of this EdgeBgpGracefulRestartConfig.
        :rtype: int
        """
        return self._stale_route_timer

    @stale_route_timer.setter
    def stale_route_timer(self, stale_route_timer):
        """
        Sets the stale_route_timer of this EdgeBgpGracefulRestartConfig.
        Maximum time (in seconds) before stale routes are removed when BGP restarts.

        :param stale_route_timer: The stale_route_timer of this EdgeBgpGracefulRestartConfig.
        :type: int
        """
        if stale_route_timer is not None and stale_route_timer > 3600:
            raise ValueError("Invalid value for `stale_route_timer`, must be a value less than or equal to `3600`")
        if stale_route_timer is not None and stale_route_timer < 1:
            raise ValueError("Invalid value for `stale_route_timer`, must be a value greater than or equal to `1`")

        self._stale_route_timer = stale_route_timer

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, EdgeBgpGracefulRestartConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
