# coding: utf-8

"""
    VMware Cloud Director OpenAPI

    VMware Cloud Director OpenAPI is a new API that is defined using the OpenAPI standards.<br/> This ReSTful API borrows some elements of the legacy VMware Cloud Director API and establishes new patterns for use as described below. <h4>Authentication</h4> Authentication and Authorization schemes are the same as those for the legacy APIs. You can authenticate using the JWT token via the <code>Authorization</code> header or specifying a session using <code>x-vcloud-authorization</code> (The latter form is deprecated). <h4>Operation Patterns</h4> This API follows the following general guidelines to establish a consistent CRUD pattern: <table> <tr>   <th>Operation</th><th>Description</th><th>Response Code</th><th>Response Content</th> </tr><tr>   <td>GET /items<td>Returns a paginated list of items<td>200<td>Response will include Navigational links to the items in the list. </tr><tr>   <td>POST /items<td>Returns newly created item<td>201<td>Content-Location header links to the newly created item </tr><tr>   <td>GET /items/urn<td>Returns an individual item<td>200<td>A single item using same data type as that included in list above </tr><tr>   <td>PUT /items/urn<td>Updates an individual item<td>200<td>Updated view of the item is returned </tr><tr>   <td>DELETE /items/urn<td>Deletes the item<td>204<td>No content is returned. </tr> </table> <h5>Asynchronous operations</h5> Asynchronous operations are determined by the server. In those cases, instead of responding as described above, the server responds with an HTTP Response code 202 and an empty body. The tracking task (which is the same task as all legacy API operations use) is linked via the URI provided in the <code>Location</code> header.<br/> All API calls can choose to service a request asynchronously or synchronously as determined by the server upon interpreting the request. Operations that choose to exhibit this dual behavior will have both options documented by specifying both response code(s) below. The caller must be prepared to handle responses to such API calls by inspecting the HTTP Response code. <h5>Error Conditions</h5> <b>All</b> operations report errors using the following error reporting rules: <ul>   <li>400: Bad Request - In event of bad request due to incorrect data or other user error</li>   <li>401: Bad Request - If user is unauthenticated or their session has expired</li>   <li>403: Forbidden - If the user is not authorized or the entity does not exist</li> </ul> <h4>OpenAPI Design Concepts and Principles</h4> <ul>   <li>IDs are full Uniform Resource Names (URNs).</li>   <li>OpenAPI's <code>Content-Type</code> is always <code>application/json</code></li>   <li>REST links are in the Link header.</li>   <ul>     <li>Multiple relationships for any link are represented by multiple values in a space-separated list.</li>     <li>Links have a custom VMware Cloud Director-specific &quot;model&quot; attribute that hints at the applicable data         type for the links.</li>     <li>title + rel + model attributes evaluates to a unique link.</li>     <li>Links follow Hypermedia as the Engine of Application State (HATEOAS) principles. Links are present if         certain operations are present and permitted for the user&quot;s current role and the state of the         referred entities.</li>   </ul>   <li>APIs follow a flat structure relying on cross-referencing other entities instead of the navigational style       used by the legacy VMware Cloud Director APIs.</li>   <li>Most endpoints that return a list support filtering and sorting similar to the query service in the legacy       VMware Cloud Director APIs.</li>   <li>Accept header must be included to specify the API version for the request similar to calls to existing legacy       VMware Cloud Director APIs.</li>   <li>Each feature has a version in the path element present in its URL.<br/>       <b>Note</b> API URL's without a version in their paths must be considered experimental.</li> </ul> 

    OpenAPI spec version: 36.0
    Contact: https://code.vmware.com/support
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class EdgeGatewayLoadBalancerConfig(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'enabled': 'bool',
        'service_network_definition': 'str',
        'load_balancer_cloud_ref': 'EntityReference',
        'license_type': 'str'
    }

    attribute_map = {
        'enabled': 'enabled',
        'service_network_definition': 'serviceNetworkDefinition',
        'load_balancer_cloud_ref': 'loadBalancerCloudRef',
        'license_type': 'licenseType'
    }

    def __init__(self, enabled=None, service_network_definition=None, load_balancer_cloud_ref=None, license_type=None):
        """
        EdgeGatewayLoadBalancerConfig - a model defined in Swagger
        """

        self._enabled = None
        self._service_network_definition = None
        self._load_balancer_cloud_ref = None
        self._license_type = None

        self.enabled = enabled
        if service_network_definition is not None:
          self.service_network_definition = service_network_definition
        if load_balancer_cloud_ref is not None:
          self.load_balancer_cloud_ref = load_balancer_cloud_ref
        if license_type is not None:
          self.license_type = license_type

    @property
    def enabled(self):
        """
        Gets the enabled of this EdgeGatewayLoadBalancerConfig.
        A flag indicating whether Load Balancer Service is enabled or not.

        :return: The enabled of this EdgeGatewayLoadBalancerConfig.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this EdgeGatewayLoadBalancerConfig.
        A flag indicating whether Load Balancer Service is enabled or not.

        :param enabled: The enabled of this EdgeGatewayLoadBalancerConfig.
        :type: bool
        """
        if enabled is None:
            raise ValueError("Invalid value for `enabled`, must not be `None`")

        self._enabled = enabled

    @property
    def service_network_definition(self):
        """
        Gets the service_network_definition of this EdgeGatewayLoadBalancerConfig.
        The network definition in Gateway CIDR format which will be used by Load Balancer service on edge. All the load balancer service engines associated with the Service Engine Group will be attached to this network. The subnet prefix length must be 25. If nothing is set, the default is <code>192.168.255.1/25</code>. Default cidr can be configured. This field cannot be updated. 

        :return: The service_network_definition of this EdgeGatewayLoadBalancerConfig.
        :rtype: str
        """
        return self._service_network_definition

    @service_network_definition.setter
    def service_network_definition(self, service_network_definition):
        """
        Sets the service_network_definition of this EdgeGatewayLoadBalancerConfig.
        The network definition in Gateway CIDR format which will be used by Load Balancer service on edge. All the load balancer service engines associated with the Service Engine Group will be attached to this network. The subnet prefix length must be 25. If nothing is set, the default is <code>192.168.255.1/25</code>. Default cidr can be configured. This field cannot be updated. 

        :param service_network_definition: The service_network_definition of this EdgeGatewayLoadBalancerConfig.
        :type: str
        """

        self._service_network_definition = service_network_definition

    @property
    def load_balancer_cloud_ref(self):
        """
        Gets the load_balancer_cloud_ref of this EdgeGatewayLoadBalancerConfig.
        Reference to the Load Balancer Cloud. This cloud is used by Edge Gateway's Load Balancer Virtual Services and Pools.

        :return: The load_balancer_cloud_ref of this EdgeGatewayLoadBalancerConfig.
        :rtype: EntityReference
        """
        return self._load_balancer_cloud_ref

    @load_balancer_cloud_ref.setter
    def load_balancer_cloud_ref(self, load_balancer_cloud_ref):
        """
        Sets the load_balancer_cloud_ref of this EdgeGatewayLoadBalancerConfig.
        Reference to the Load Balancer Cloud. This cloud is used by Edge Gateway's Load Balancer Virtual Services and Pools.

        :param load_balancer_cloud_ref: The load_balancer_cloud_ref of this EdgeGatewayLoadBalancerConfig.
        :type: EntityReference
        """

        self._load_balancer_cloud_ref = load_balancer_cloud_ref

    @property
    def license_type(self):
        """
        Gets the license_type of this EdgeGatewayLoadBalancerConfig.
        The license type of the backing Load Balancer Cloud. <ul> <li>BASIC - Basic edition of the NSX Advanced Load Balancer. <li>ENTERPRISE - Full featured edition of the NSX Advanced Load Balancer. </ul> 

        :return: The license_type of this EdgeGatewayLoadBalancerConfig.
        :rtype: str
        """
        return self._license_type

    @license_type.setter
    def license_type(self, license_type):
        """
        Sets the license_type of this EdgeGatewayLoadBalancerConfig.
        The license type of the backing Load Balancer Cloud. <ul> <li>BASIC - Basic edition of the NSX Advanced Load Balancer. <li>ENTERPRISE - Full featured edition of the NSX Advanced Load Balancer. </ul> 

        :param license_type: The license_type of this EdgeGatewayLoadBalancerConfig.
        :type: str
        """

        self._license_type = license_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, EdgeGatewayLoadBalancerConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
