# coding: utf-8

"""
    VMware Cloud Director OpenAPI

    VMware Cloud Director OpenAPI is a new API that is defined using the OpenAPI standards.<br/> This ReSTful API borrows some elements of the legacy VMware Cloud Director API and establishes new patterns for use as described below. <h4>Authentication</h4> Authentication and Authorization schemes are the same as those for the legacy APIs. You can authenticate using the JWT token via the <code>Authorization</code> header or specifying a session using <code>x-vcloud-authorization</code> (The latter form is deprecated). <h4>Operation Patterns</h4> This API follows the following general guidelines to establish a consistent CRUD pattern: <table> <tr>   <th>Operation</th><th>Description</th><th>Response Code</th><th>Response Content</th> </tr><tr>   <td>GET /items<td>Returns a paginated list of items<td>200<td>Response will include Navigational links to the items in the list. </tr><tr>   <td>POST /items<td>Returns newly created item<td>201<td>Content-Location header links to the newly created item </tr><tr>   <td>GET /items/urn<td>Returns an individual item<td>200<td>A single item using same data type as that included in list above </tr><tr>   <td>PUT /items/urn<td>Updates an individual item<td>200<td>Updated view of the item is returned </tr><tr>   <td>DELETE /items/urn<td>Deletes the item<td>204<td>No content is returned. </tr> </table> <h5>Asynchronous operations</h5> Asynchronous operations are determined by the server. In those cases, instead of responding as described above, the server responds with an HTTP Response code 202 and an empty body. The tracking task (which is the same task as all legacy API operations use) is linked via the URI provided in the <code>Location</code> header.<br/> All API calls can choose to service a request asynchronously or synchronously as determined by the server upon interpreting the request. Operations that choose to exhibit this dual behavior will have both options documented by specifying both response code(s) below. The caller must be prepared to handle responses to such API calls by inspecting the HTTP Response code. <h5>Error Conditions</h5> <b>All</b> operations report errors using the following error reporting rules: <ul>   <li>400: Bad Request - In event of bad request due to incorrect data or other user error</li>   <li>401: Bad Request - If user is unauthenticated or their session has expired</li>   <li>403: Forbidden - If the user is not authorized or the entity does not exist</li> </ul> <h4>OpenAPI Design Concepts and Principles</h4> <ul>   <li>IDs are full Uniform Resource Names (URNs).</li>   <li>OpenAPI's <code>Content-Type</code> is always <code>application/json</code></li>   <li>REST links are in the Link header.</li>   <ul>     <li>Multiple relationships for any link are represented by multiple values in a space-separated list.</li>     <li>Links have a custom VMware Cloud Director-specific &quot;model&quot; attribute that hints at the applicable data         type for the links.</li>     <li>title + rel + model attributes evaluates to a unique link.</li>     <li>Links follow Hypermedia as the Engine of Application State (HATEOAS) principles. Links are present if         certain operations are present and permitted for the user&quot;s current role and the state of the         referred entities.</li>   </ul>   <li>APIs follow a flat structure relying on cross-referencing other entities instead of the navigational style       used by the legacy VMware Cloud Director APIs.</li>   <li>Most endpoints that return a list support filtering and sorting similar to the query service in the legacy       VMware Cloud Director APIs.</li>   <li>Accept header must be included to specify the API version for the request similar to calls to existing legacy       VMware Cloud Director APIs.</li>   <li>Each feature has a version in the path element present in its URL.<br/>       <b>Note</b> API URL's without a version in their paths must be considered experimental.</li> </ul> 

    OpenAPI spec version: 36.0
    Contact: https://code.vmware.com/support
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ExternalNetworkBacking(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'backing_id': 'str',
        'backing_type': 'ExternalNetworkBackingType',
        'backing_type_value': 'str',
        'network_provider': 'EntityReference',
        'name': 'str',
        'parent_tier0_ref': 'ExtObjectReference'
    }

    attribute_map = {
        'backing_id': 'backingId',
        'backing_type': 'backingType',
        'backing_type_value': 'backingTypeValue',
        'network_provider': 'networkProvider',
        'name': 'name',
        'parent_tier0_ref': 'parentTier0Ref'
    }

    def __init__(self, backing_id=None, backing_type=None, backing_type_value=None, network_provider=None, name=None, parent_tier0_ref=None):
        """
        ExternalNetworkBacking - a model defined in Swagger
        """

        self._backing_id = None
        self._backing_type = None
        self._backing_type_value = None
        self._network_provider = None
        self._name = None
        self._parent_tier0_ref = None

        if backing_id is not None:
          self.backing_id = backing_id
        if backing_type is not None:
          self.backing_type = backing_type
        if backing_type_value is not None:
          self.backing_type_value = backing_type_value
        if network_provider is not None:
          self.network_provider = network_provider
        if name is not None:
          self.name = name
        if parent_tier0_ref is not None:
          self.parent_tier0_ref = parent_tier0_ref

    @property
    def backing_id(self):
        """
        Gets the backing_id of this ExternalNetworkBacking.
        Unique identifier for the network backing in NSX/vCenter.

        :return: The backing_id of this ExternalNetworkBacking.
        :rtype: str
        """
        return self._backing_id

    @backing_id.setter
    def backing_id(self, backing_id):
        """
        Sets the backing_id of this ExternalNetworkBacking.
        Unique identifier for the network backing in NSX/vCenter.

        :param backing_id: The backing_id of this ExternalNetworkBacking.
        :type: str
        """

        self._backing_id = backing_id

    @property
    def backing_type(self):
        """
        Gets the backing_type of this ExternalNetworkBacking.
        Type of network backing. This is deprecated in favor of string based enums going forward.

        :return: The backing_type of this ExternalNetworkBacking.
        :rtype: ExternalNetworkBackingType
        """
        return self._backing_type

    @backing_type.setter
    def backing_type(self, backing_type):
        """
        Sets the backing_type of this ExternalNetworkBacking.
        Type of network backing. This is deprecated in favor of string based enums going forward.

        :param backing_type: The backing_type of this ExternalNetworkBacking.
        :type: ExternalNetworkBackingType
        """

        self._backing_type = backing_type

    @property
    def backing_type_value(self):
        """
        Gets the backing_type_value of this ExternalNetworkBacking.
        Backing type for the network. <ul> <li>PORTGROUP</li> <li>DV_PORTGROUP</li> <li>NSXT_TIER0</li> <li>NSXT_VRF_TIER0</li> <li>IMPORTED_T_LOGICAL_SWITCH</li> <li>UNKNOWN</li> </ul> 

        :return: The backing_type_value of this ExternalNetworkBacking.
        :rtype: str
        """
        return self._backing_type_value

    @backing_type_value.setter
    def backing_type_value(self, backing_type_value):
        """
        Sets the backing_type_value of this ExternalNetworkBacking.
        Backing type for the network. <ul> <li>PORTGROUP</li> <li>DV_PORTGROUP</li> <li>NSXT_TIER0</li> <li>NSXT_VRF_TIER0</li> <li>IMPORTED_T_LOGICAL_SWITCH</li> <li>UNKNOWN</li> </ul> 

        :param backing_type_value: The backing_type_value of this ExternalNetworkBacking.
        :type: str
        """

        self._backing_type_value = backing_type_value

    @property
    def network_provider(self):
        """
        Gets the network_provider of this ExternalNetworkBacking.
        The Network Provider for the backing, either a vCenter Server or NSX-T Manager.

        :return: The network_provider of this ExternalNetworkBacking.
        :rtype: EntityReference
        """
        return self._network_provider

    @network_provider.setter
    def network_provider(self, network_provider):
        """
        Sets the network_provider of this ExternalNetworkBacking.
        The Network Provider for the backing, either a vCenter Server or NSX-T Manager.

        :param network_provider: The network_provider of this ExternalNetworkBacking.
        :type: EntityReference
        """

        self._network_provider = network_provider

    @property
    def name(self):
        """
        Gets the name of this ExternalNetworkBacking.
        The name of this external network backing, if it exists.

        :return: The name of this ExternalNetworkBacking.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ExternalNetworkBacking.
        The name of this external network backing, if it exists.

        :param name: The name of this ExternalNetworkBacking.
        :type: str
        """

        self._name = name

    @property
    def parent_tier0_ref(self):
        """
        Gets the parent_tier0_ref of this ExternalNetworkBacking.
        If this external network is backed by a NSX-T VRF-Lite Tier0, then this field is set to be the parent Tier0 Router.  Otherwise, field is unset.

        :return: The parent_tier0_ref of this ExternalNetworkBacking.
        :rtype: ExtObjectReference
        """
        return self._parent_tier0_ref

    @parent_tier0_ref.setter
    def parent_tier0_ref(self, parent_tier0_ref):
        """
        Sets the parent_tier0_ref of this ExternalNetworkBacking.
        If this external network is backed by a NSX-T VRF-Lite Tier0, then this field is set to be the parent Tier0 Router.  Otherwise, field is unset.

        :param parent_tier0_ref: The parent_tier0_ref of this ExternalNetworkBacking.
        :type: ExtObjectReference
        """

        self._parent_tier0_ref = parent_tier0_ref

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ExternalNetworkBacking):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
